function  [alpha, L, gradient, w0, pos, Alpsup] = adjustSVMSoft(kernels, radiusSquared, mu, C, Y)

%Using two step algorithm, so here mu is fixed
%maximize L subject to  0 <= alpha 
% Use L2 soft margin

%Param: kernels : cell of component kernel matrices
%Param: radius: component radius
%Param: mu: weights of component kernels

%----------------------------------
%Some checks
%----------------------------------
if (find(mu <-0.000001))
    fprintf('mu should be positive  \n');
    alpha = 0;
    L = 0;
    gradient= 0;
    w0 = 0;
    pos=[];
    Alpsup = [];
    return;
end
%----------------------------------
%End Some checks
%----------------------------------

numKernels = length(mu);
[numInstances nCol]= size(kernels{1});

%---------------------------------------------------------
%Compute linear combination of component radius squared.
%Compute the linear combination of kernels.
%---------------------------------------------------------

R2 = 0; %radius squared
K = zeros(numInstances,numInstances);
for k = 1:numKernels
    R2 = R2 +radiusSquared(k)*mu(k);
    K = K + mu(k)* kernels{k};
end
% fprintf('Current value of R squared %f \n', R2)  ;
%-----------------------------------------------------------
%% Use L2 soft margin, so we have to adjust K 
C2 = C/R2;
delta = eye(numInstances, numInstances);
delta = delta * 1/C2;
K = K + delta;
%End Adjust K 
%-----------------------------------------------------------

H = K.*(Y*Y');
f = ones(numInstances,1);
%------------------------------------------------------------

%----------------------------------------------------------------

%% Use function in SimpleMKL: monpq, monpqCinfty
%----------------------------------------------------------------------
%      monqp(H,c,A,b,C) solves the quadratic programming problem:
% 
%    min 0.5*x'Hx - c'x   subject to:  A'x = b  and  0 <= x <= C 
%     x    
%----------------------------------------------------------------------
%Here we use L2 soft margin, so C = Inf 

b = 0;   
options.lambdareg = 1e-8;                                                        
[alpha , lambda , pos] = monqpCinfty(H,f,Y,b,options.lambdareg);         
% 
%alpha: only nonzero value is stored , positions of these values are stored in pos
alpha_nonzero = alpha;
alphaall=zeros(size(f)); % alphaall: all values, include zero values.
alphaall(pos)=alpha;
obj=0.5*alphaall'*H*alphaall -f'*alphaall;
L = -obj;

ysup = Y(pos);
Alpsup = alpha.*ysup;
w0 = lambda;

alpha = alphaall; % now alpha is all values, include zero values.



%% Gradient
gradient = zeros(numKernels,1);

%derivative of L subject to mu_k
for k = 1: numKernels
    delta_k = eye(numInstances, numInstances);
    delta_k = delta_k * radiusSquared(k)/C;
    
    Hk = (kernels{k} + delta_k).* (Y*Y') ;
    
    gradient(k) = -0.5* alpha_nonzero'*Hk(pos,pos)*alpha_nonzero ;
   
 end

