function [R2] = componentRadiusSquared(kernel)

%% use quadprog function
%Standard quadprog in Matlab is too slow and the MaxIter is small
% It often give non-optimal result!!!
%So use monqp instead of quadprog
% f= zeros(numInstances,1); % column vector
% for i= 1: numInstances
%     f(i,1) = -1 * kernel(i,i);
% end
% H = 2 * kernel;
% A = -1 *eye(numInstances); 
% b = zeros(numInstances,1); 
% beq = 1;
% Aeq = ones(1,numInstances);
% 
% [beta, R2] = quadprog(H, f,A,b,Aeq,beq);
% R2 = -1* R2;
% %R2 : radius squared

%%
%----------------------------------------------------------------------
%      monqpCinfty(H,b,c) solves the quadratic programming problem:
% 
%    min 0.5*x'Hx - d'x   subject to:  A'x = b  and  0 <= x 
%     x    
%----------------------------------------------------------------------
% function [xnew, lambda, ind] = monqp0(H,c,A,b,l,verbose,X,ps)
%
% min 1/2  x' H x - c' x                
%  x 
% contrainte   A' x = b                     y'*x = 0 
% 
% et         0 <= x 

[numInstances, nCol] = size(kernel);
H = 2 * kernel;
Aeq = ones(numInstances,1); 
beq = 1;

c= zeros(numInstances,1); % column vector
 for i= 1: numInstances
     c(i,1) = kernel(i,i);
 end

[alpha, lambda, ind] = monqpCinfty(H,c,Aeq,beq);

alphaall=zeros(size(c));
alphaall(ind)=alpha;
obj=0.5*alphaall'*H*alphaall -c'*alphaall;

%R2 : radius squared
 R2 = -1* obj;
 
%% R2 using cvx toolbox
%% very fast as monqp
% [numInstances, nCol] = size(kernel);
% H = 2 * kernel;
% c= zeros(numInstances,1); % column vector
% for i= 1: numInstances
%      c(i,1) = kernel(i,i);
%  end
% C = ones(1,numInstances);
% cvx_begin
%     variable alpha(numInstances)
%     minimize ((1/2)*quad_form(alpha,H) - c'*alpha );
%     subject to
%         C*alpha == 1;
%         alpha >= 0;
%    
% cvx_end
% R2 = cvx_optval;
