function [w,d,pos,alpha,obj]= svmLargeScaleL2Class(y,kernel,C,lambda,verbose)
% USAGE [w,b,pos,timeps,alpha]=svmclass(y,c,lambda,kernel,kerneloption,verbose,span)
%
% Support vector machine for CLASSIFICATION
% with quadratic penalty
% This routine classify the training set with a support vector machine
% using quadratic programming algorithm (active constraints method)
%
% INPUT
%
% Training set
%      x  		: input data %not necessary
%      y  		: output data
% parameters
%		C		: Bound on the lagrangian multipliers     
%		lambda		: Conditioning parameter for QP method
%		kernel		: kernel  matrix

%
% 		verbose : display outputs (default value is 0: no display)
%
%
%
% OUTPUT
%
% xsup	coordinates of the Support Vector
% w      weight
% b		bias
% pos    position of Support Vector
% alpha  Lagragian multiplier
% obj    Value of Objective function
%
%
% see also svmreg, svmkernel, svmval
	
%	21/09/97 S. Canu
%	04/06/00 A. Rakotomamonjy   -inclusion of other kernel functions
%	04/05/01 S. Canu            -inclusion of multi-constraint optimization for frame-SVM
%
%       scanu@insa-rouen.fr, alain.rakoto@insa-rouen.fr



if nargin< 9
    alphainit=[];
end;


if nargin < 8
	A = y;
    b = 0;
else
    if span == 1
        span=ones(size(y));
    end
	[na,m]=size(span);
        [n un] = size(y);
        if n ~= na
	        error('span, x and y  must have the same number of row')
        end
        A = (y*ones(1,m)).*span;
        b = zeros(m,1);
end

if nargin < 7
	verbose = 0;
end

if nargin < 6
	gamma = 1;
end


if nargin < 5
	lambda = 0.000000001;
end

if nargin < 4
	C = inf;
end

[n un] = size(y);

if min(y) ~= -1
	error(' y must coded: 1 for class one and -1 for class two')
end


ps= kernel;

if size(C,1)==n
    ps=ps+diag(1./C);
else
    ps=ps+1/C*eye(n);
end;
%----------------------------------------------------------------------
%      monqpCinfty(H,c,A,b) solves the quadratic programming problem:
%  
% min 1/2  x' H x - c' x                
%  x 
% contrainte   A' x = b                     y'*x = 0 
% 
% et         0 <= x 
%----------------------------------------------------------------------
H =ps.*(y*y'); 
e = ones(size(y));

                                                          
[alpha , lambda , pos] =  monqpCinfty(H,e,A,b,lambda,verbose);  


if verbose ~= 0 
    disp('out QP'); 
end;

alphaall=zeros(size(e));
alphaall(pos)=alpha;
obj=-0.5*alphaall'*H*alphaall +e'*alphaall;
ysup = y(pos);
w = (alpha.*ysup);
d = lambda;

if verbose ~= 0  
	disp('max(alpha)') 
	fprintf(1,'%6.2f\n',max(alpha)) 
end 
