function  [mu currentCost alpha Alpsup w0 pos] = twoStepAlgSoft(kernels, radiusSquared, C, Y,mu, option )

numKernels = length(kernels);

%---------------------------------------------------------
%Initialize mu
%----------------------------------------------------------

if nargin< 5
    mu = ones(numKernels,1)/numKernels;
end;

%-----------------------------------------------------------
%End Initialize mu
%-----------------------------------------------------------

%----------------------------------------------------------
%Initialize parameters
%-----------------------------------------------------------
option.numericalprecision = (1/numKernels)/100;
option.goldensearch_deltmax = 1e-1;
option.goldensearchmax=1e-5;% old value 1e-7;
option.maxIter = 1000;
option.epsilon = 0.01;
goldensearch_deltmaxinit= option.goldensearch_deltmax;
option.seuildiffsigma=1e-5;
seuil = 1e-12;
iteration = 0;
option.seuildualitygap= 0.01;

%----------------------------------------------------------
%End Initialize parameters
%-----------------------------------------------------------

%-------------------------------------------------------------
%For initial value of mu, compute standard SVM L2 soft margin.
%-------------------------------------------------------------
[alpha, currentCost, gradient, w0, pos, Alpsup] = adjustSVMSoft(kernels, radiusSquared, mu, C, Y);
  
muOld = mu;

while iteration < option.maxIter  
    iteration = iteration + 1;
    
    %------------------------------------------------------------
    %Update value of mu
    %------------------------------------------------------------
    % fprintf('Update mu ... \n');
    
    [mu, Alpsup, obj, w0, pos] = updateStepSoft(kernels, radiusSquared, mu, gradient, currentCost,option,C,Y);
   

    
    %---------------------------------------------------------
    %For current mu, compute standard SVM L2 soft margin.
    %---------------------------------------------------------
    [alpha, currentCost, gradient, w0, pos, Alpsup] = adjustSVMSoft(kernels, radiusSquared, mu, C, Y);
    
    %-----------------------------------------------------
    % check nbiteration conditions
    %----------------------------------------------------

    if(iteration >=option.maxIter  )
       fprintf(1,'maximum number of iterations reached\n')  ;
    end
    %-----------------------------------------------------
    %check KKT conditions
    %-----------------------------------------------------
    
    indexPositive = find(mu > option.numericalprecision);
    gradientMin = min(gradient(indexPositive));
    gradientMax = max(gradient(indexPositive));
    %gradient
    indexZero =  find(mu <= option.numericalprecision);
    
    if((abs(gradientMax-gradientMin) < option.epsilon) & (gradient(indexZero) >= gradientMax))
        fprintf(' (gradientMax-gradientMin) < option.epsilon;  currentCost = %f \n', currentCost);
        break;
    end
    if(max(abs(mu - muOld))<option.seuildiffsigma  & option.goldensearch_deltmax <=option.goldensearchmax)
         fprintf('abs(mu - muOld))<option.seuildiffsigma;  currentCost = %f \n', currentCost);
        break;
    end

    %----------------------------------------------------
    % check duality gap
    %----------------------------------------------------
     
    normek=-gradient; 
    dualitygap=(currentCost +   max(normek) - sum(abs(alpha)))/currentCost;
    if (dualitygap < option.seuildualitygap)
        fprintf('Duality gap criteria reached ; currentCost = %f \n', currentCost);
        break;
    end
       
    %-----------------------------------------------------------
    % Enhance accuracy of line search if necessary
    %-----------------------------------------------------------
    if max(abs(mu-muOld))<option.numericalprecision & option.goldensearch_deltmax > option.goldensearchmax
        option.goldensearch_deltmax=option.goldensearch_deltmax/10;
    elseif option.goldensearch_deltmax~=goldensearch_deltmaxinit
        option.goldensearch_deltmax*10;
    end;
    
    %---------------------------------------------------------------
    % Clean value of mu (if mu_k is smaller than the threashold, supress
    % it to 0.
    %---------------------------------------------------------------
    if seuil ~=0 & max(mu)>seuil
        mu = (mu.*(mu>seuil))*sum(mu)/sum(mu.*(mu>seuil));
    end
    mu(find(abs(mu<option.numericalprecision)))=0;
    mu=mu/sum(mu);

    %--------------------------------------------------------
    % mu becomes muOld
    %--------------------------------------------------------
    muOld = mu;
   % fprintf('sum(mu > mean(mu) %g, sum(mu==0) = %g\n', sum(mu > mean(mu)), sum(mu==0) );

    
end
