function [mu , Alpsup, CostNew, w0, pos] = updateStepSoft(kernels, radiusSquared,mu, gradient, currentCost,option, C, Y)
%------------------------------------------------
%Compute descent gradient direction and optimal (maximum) step to update
%------------------------------------------------
Alpsup=[];
w0=[];
pos=[];
CostNew = NaN;
normGrad = gradient'*gradient;
gradient=gradient/sqrt(normGrad);
option.numericalprecision = 1e-4; %old value 1e-7;

%---------------------------------------------------------------
% Compute reduced Gradient and descent direction % page 401 Reduced
% Gradient Algorithm. (Wolfe's reduced gradient algorithm)
%%--------------------------------------------------------------

[val,coord] = max(mu); %Chose coord to be the index of the largest component of vector mu
%for better numerical stability (Bonnans 2006)
gradient = gradient - gradient(coord);

descentDirection = -gradient .*( (mu >0 | gradient < 0 ));
descentDirection(coord) =  -sum(descentDirection);


%----------------------------------------------------
% Compute optimal stepsize
%-----------------------------------------------------
stepmin  = 0;
costmin  = currentCost ; %cost function or L = J(mu) at previous step
costmax  = 0 ;
%-----------------------------------------------------
% maximum stepsize
%-----------------------------------------------------
index = find(descentDirection < 0 );
stepmax = min(-(mu(index))./descentDirection(index));
deltmax = stepmax;
if isempty(stepmax)| stepmax < option.numericalprecision 

    return;
end
if stepmax > 0.1
     stepmax=0.1;
end;

%-----------------------------------------------------
%  Projected gradient
%-----------------------------------------------------
 
    
while costmax<costmin
    muNew = mu + stepmax * descentDirection;
    [alphaNew, costmax, gradientNew, w0aux,posaux, Alpsupaux]  = adjustSVMSoft(kernels, radiusSquared, muNew, C, Y);

     
    if(costmax < costmin)
        costmin = costmax;
        mu = muNew;
        descentDirection = descentDirection .* ( (mu>option.numericalprecision) | (descentDirection>0) ) ;
        descentDirection(coord) = - sum(descentDirection([[1:coord-1] [coord+1:end]]));   
        ind = find(descentDirection<0);
        
        Alpsup=Alpsupaux;
        w0=w0aux;
        pos=posaux;
        
        if ~isempty(ind)
            stepmax = min(-(mu(ind))./descentDirection(ind));
            deltmax = stepmax;
            costmax = 0;
        else
            stepmax = 0;
            deltmax = 0;
        end;
    
    end
    
end

%stepmax
%-----------------------------------------------------
%  Linesearch
%-----------------------------------------------------

Step = [stepmin stepmax];
Cost = [costmin costmax];
gold = (sqrt(5)+1)/2 ;
[val,coord] = min(Cost);
% optimization of stepsize by golden search
while (stepmax-stepmin)>option.goldensearch_deltmax*(abs(deltmax))  & stepmax > eps;
    stepmedr = stepmin+(stepmax-stepmin)/gold;
    stepmedl = stepmin+(stepmedr-stepmin)/gold;   
 
    muNewr = mu + stepmedr * descentDirection;
    muNewl = mu + stepmedl * descentDirection;
    [alphaNew, costmedr, gradientNewr, w0r, posr, Alpsupr]  = adjustSVMSoft(kernels, radiusSquared, muNewr, C, Y);
    %costmedr
    [alphaNew, costmedl, gradientNewl, w0l, posl, Alpsupl]  = adjustSVMSoft(kernels, radiusSquared, muNewl, C, Y);
    %costmedl
     
    
    Step = [stepmin stepmedl stepmedr stepmax];
    Cost = [costmin costmedl costmedr costmax];
    [val,coord] = min(Cost);
    switch coord
        case 1
            stepmax = stepmedl;
            costmax = costmedl;
            pos=posl;
            Alpsup=Alpsupl;
            w0=w0l;
        case 2
            stepmax = stepmedr;
            costmax = costmedr;
            pos=posr;
            Alpsup=Alpsupr;
            w0=w0r;
        case 3
            stepmin = stepmedl;
            costmin = costmedl;
            pos=posl;
            Alpsup=Alpsupl;
            w0=w0l;
        case 4
            stepmin = stepmedr;
            costmin = costmedr;
            pos=posr;
            Alpsup=Alpsupr;
            w0=w0r;
    end;
end;


%---------------------------------
% Final Updates
%---------------------------------

CostNew = Cost(coord) ;
step = Step(coord) ;
% mu update
if CostNew < currentCost ;
    mu = mu + step * descentDirection;  
end;       
%mu
%sum(mu)


